@@ -13,7 +13,7 @@
 #    License for the specific language governing permissions and limitations
 #    under the License.
 
-import mock
+from unittest import mock
 
 from neutron.db import servicetype_db as st_db
 from neutron_lib import context as n_ctx
@@ -67,7 +67,7 @@ class TestValidatorSelection(base.BaseTestCase):
             mock.patch.object(st_db.ServiceTypeManager,
                               'get_service_providers').start())
         self.service_providers.return_value = vpnaas_provider
-        mock.patch('neutron.common.rpc.Connection').start()
+        mock.patch('neutron_lib.rpc.Connection').start()
         stm = st_db.ServiceTypeManager()
         stm.get_provider_names_by_resource_ids = mock.Mock(
             return_value={})
@@ -87,7 +87,7 @@ class TestValidatorSelection(base.BaseTestCase):
 class TestIPsecDriver(base.BaseTestCase):
     def setUp(self):
         super(TestIPsecDriver, self).setUp()
-        mock.patch('neutron.common.rpc.Connection').start()
+        mock.patch('neutron_lib.rpc.Connection').start()
 
         l3_agent = mock.Mock()
         l3_agent.host = FAKE_HOST
@@ -98,9 +98,8 @@ class TestIPsecDriver(base.BaseTestCase):
         self.svc_plugin = mock.Mock()
         self.svc_plugin.get_l3_agents_hosting_routers.return_value = [l3_agent]
         self._fake_vpn_router_id = _uuid()
-        self.svc_plugin._get_vpnservice.return_value = {
-            'router_id': self._fake_vpn_router_id
-        }
+        self.svc_plugin.get_vpnservice_router_id.return_value = \
+            self._fake_vpn_router_id
         self.driver = ipsec_driver.IPsecVPNDriver(self.svc_plugin)
         self.validator = ipsec_validator.IpsecVpnValidator(self.driver)
         self.context = n_ctx.get_admin_context()
